<html>
  <head>
	<title>LTI Error</title>
	<link rel="stylesheet" href="//cdnjs.cloudflare.com/ajax/libs/pure/0.4.2/pure-min.css" />
	<style type="text/css">
	  body { 
	    padding: 1em;
	  }
	</style>
  </head>
  <body>
	<h1>xSifTx - LTI Error</h1>
	<p>
	  {{ message }}
	</p>
  </body>
</html>
